@@ -15,13 +15,16 @@ impl<'a> Request<'a> {
     ///
     /// This method accepts no arguments.
 
-    pub fn query_string(&'a mut self) -> String {
-        match &self.query {
-            // If query string has already been built, return it:
-            Some(query_string) => query_string.to_owned(),
-            // If it hasn't been built, build it:
-            None => self.build().query.as_ref().unwrap().clone(),
-        } // match
+    pub fn query_string(&'a mut self) -> (String, String) {
+        (
+            "https://maps.googleapis.com/maps/api/timezone/json?".to_string(),
+            match &self.query {
+                // If query string has already been built, return it:
+                Some(query_string) => query_string.to_owned(),
+                // If it hasn't been built, build it:
+                None => self.build().query.as_ref().unwrap().clone(),
+            } // match
+        )
     } // fn
 
 } // impl
\ No newline at end of file
